==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFieldValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridValidationStateDescriptionMetadata } from "./WebGridValidationStateDescriptionMetadata";
import { WebFieldValidationStateDescription } from "./WebFieldValidationStateDescription";
/**
 * @hidden
 */
export let WebFieldValidationStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFieldValidationStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebFieldValidationStateDescriptionMetadata.a == null) {
                WebFieldValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFieldValidationStateDescriptionMetadata.c(WebFieldValidationStateDescriptionMetadata.a);
            }
            if (a.j(WebFieldValidationStateDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFieldValidationStateDescriptionMetadata.a);
        }
        static c(a) {
            WebGridValidationStateDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FieldValidationState");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Field", "String");
        }
        static d(a) {
            WebFieldValidationStateDescriptionMetadata.b(a);
            a.aa("WebFieldValidationState", () => new WebFieldValidationStateDescription());
            a.z("WebFieldValidationState", WebFieldValidationStateDescriptionMetadata.a);
        }
    }
    WebFieldValidationStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFieldValidationStateDescriptionMetadata, 'WebFieldValidationStateDescriptionMetadata');
    WebFieldValidationStateDescriptionMetadata.a = null;
    return WebFieldValidationStateDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFieldValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridValidationStateDescriptionMetadata } from "./WebGridValidationStateDescriptionMetadata";
import { WebFieldValidationStateDescription } from "./WebFieldValidationStateDescription";
/**
 * @hidden
 */
export let WebFieldValidationStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFieldValidationStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebFieldValidationStateDescriptionMetadata.a == null) {
                WebFieldValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFieldValidationStateDescriptionMetadata.c(WebFieldValidationStateDescriptionMetadata.a);
            }
            if (a.k(WebFieldValidationStateDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFieldValidationStateDescriptionMetadata.a);
        }
        static c(a) {
            WebGridValidationStateDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FieldValidationState");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("Field", "String");
        }
        static d(a) {
            WebFieldValidationStateDescriptionMetadata.b(a);
            a.ac("WebFieldValidationState", () => new WebFieldValidationStateDescription());
            a.ab("WebFieldValidationState", WebFieldValidationStateDescriptionMetadata.a);
        }
    }
    WebFieldValidationStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFieldValidationStateDescriptionMetadata, 'WebFieldValidationStateDescriptionMetadata');
    WebFieldValidationStateDescriptionMetadata.a = null;
    return WebFieldValidationStateDescriptionMetadata;
})();
